@@ -1,3 +1,13 @@
+"""WorkspaceOneAPI Client Module
+
+The module handles all basic methods to interact with the API.
+Basic HTTP Method calls are defined here (GET, POST, PUT, PATCH, DELETE)
+and static methods for error checking, building the client object and constructing header values.
+
+In Case of errors in the response the requests will raise an exception
+using the WorkspaceOneAPIError Class.
+"""
+
 from __future__ import print_function, absolute_import
 import base64
 import logging
@@ -6,7 +16,9 @@ from pyws1uem.error import WorkspaceOneAPIError
 from pyws1uem.mdm.devices import Devices
 from pyws1uem.system.groups import Groups
 from pyws1uem.system.users import Users
-from pyws1uem.system.system import System
+from pyws1uem.system.info import Info
+from pyws1uem.mdm.tags import Tags
+
 
 # Enabling debugging at http.client level (requests->urllib3->http.client)
 # you will see the REQUEST, including HEADERS and DATA, and RESPONSE with
@@ -20,7 +32,7 @@ HTTPConnection.debuglevel = 0
 
 # TODO: programing using library should be able to set logging level
 # TODO: Implement logging to using config https://docs.python.org/3/howto/logging.html#configuring-logging
-# TODO: sett logging correclty for a library https://docs.python.org/3/howto/logging.html#configuring-logging-for-a-library
+# TODO: sett logging correctly for a library https://docs.python.org/3/howto/logging.html#configuring-logging-for-a-library
 logging.basicConfig()
 logging.getLogger().setLevel(logging.DEBUG)
 requests_log = logging.getLogger("requests.packages.urllib3")
@@ -29,6 +41,10 @@ requests_log.propagate = True
 
 
 class WorkspaceOneAPI(object):
+    """
+    Class for building a WorkspaceONE UEM API Object
+    """
+
     def __init__(self, env: str, apikey: str, username: str, password: str):
         """
         Initialize an AirWatchAPI Client Object.
@@ -45,7 +61,8 @@ class WorkspaceOneAPI(object):
         self.groups = Groups(self)
         self.devices = Devices(self)
         self.users = Users(self)
-        self.system = System(self)
+        self.info = Info(self)
+        self.tags = Tags(self)
 
     def get(self, module, path, version=None, params=None, header=None, timeout=30):
         """
@@ -54,16 +71,18 @@ class WorkspaceOneAPI(object):
         if header is None:
             header = {}
         header.update(
-            self._build_header(self.username, self.password, self.apikey, header)
+            self._build_header(self.username, self.password,
+                               self.apikey, header)
         )
         header.update({"Content-Type": "application/json"})
         endpoint = self._build_endpoint(self.env, module, path, version)
         try:
-            r = requests.get(endpoint, params=params, headers=header, timeout=timeout)
-            r = self._check_for_error(r)
-            return r
-        except WorkspaceOneAPIError as e:
-            raise e
+            api_response = requests.get(
+                endpoint, params=params, headers=header, timeout=timeout)
+            api_response = self._check_for_error(api_response)
+            return api_response
+        except WorkspaceOneAPIError as api_error:
+            raise api_error
 
     def post(
         self,
@@ -82,11 +101,12 @@ class WorkspaceOneAPI(object):
         if header is None:
             header = {}
         header.update(
-            self._build_header(self.username, self.password, self.apikey, header)
+            self._build_header(self.username, self.password,
+                               self.apikey, header)
         )
         endpoint = self._build_endpoint(self.env, module, path, version)
         try:
-            r = requests.post(
+            api_response = requests.post(
                 endpoint,
                 params=params,
                 data=data,
@@ -94,10 +114,10 @@ class WorkspaceOneAPI(object):
                 headers=header,
                 timeout=timeout,
             )
-            r = self._check_for_error(r)
-            return r
-        except WorkspaceOneAPIError as e:
-            raise e
+            api_response = self._check_for_error(api_response)
+            return api_response
+        except WorkspaceOneAPIError as api_error:
+            raise api_error
 
     def put(
         self,
@@ -116,11 +136,12 @@ class WorkspaceOneAPI(object):
         if header is None:
             header = {}
         header.update(
-            self._build_header(self.username, self.password, self.apikey, header)
+            self._build_header(self.username, self.password,
+                               self.apikey, header)
         )
         endpoint = self._build_endpoint(self.env, module, path, version)
         try:
-            r = requests.put(
+            api_response = requests.put(
                 endpoint,
                 params=params,
                 data=data,
@@ -128,10 +149,10 @@ class WorkspaceOneAPI(object):
                 headers=header,
                 timeout=timeout,
             )
-            r = self._check_for_error(r)
-            return r
-        except WorkspaceOneAPIError as e:
-            raise e
+            api_response = self._check_for_error(api_response)
+            return api_response
+        except WorkspaceOneAPIError as api_error:
+            raise api_error
 
     def patch(
         self,
@@ -150,11 +171,12 @@ class WorkspaceOneAPI(object):
         if header is None:
             header = {}
         header.update(
-            self._build_header(self.username, self.password, self.apikey, header)
+            self._build_header(self.username, self.password,
+                               self.apikey, header)
         )
         endpoint = self._build_endpoint(self.env, module, path, version)
         try:
-            r = requests.patch(
+            api_response = requests.patch(
                 endpoint,
                 params=params,
                 data=data,
@@ -162,10 +184,10 @@ class WorkspaceOneAPI(object):
                 headers=header,
                 timeout=timeout,
             )
-            r = self._check_for_error(r)
-            return r
-        except WorkspaceOneAPIError as e:
-            raise e
+            api_response = self._check_for_error(api_response)
+            return api_response
+        except WorkspaceOneAPIError as api_error:
+            raise api_error
 
     # NOQA
 
@@ -186,11 +208,12 @@ class WorkspaceOneAPI(object):
         if header is None:
             header = {}
         header.update(
-            self._build_header(self.username, self.password, self.apikey, header)
+            self._build_header(self.username, self.password,
+                               self.apikey, header)
         )
         endpoint = self._build_endpoint(self.env, module, path, version)
         try:
-            r = requests.delete(
+            api_response = requests.delete(
                 endpoint,
                 params=params,
                 data=data,
@@ -198,10 +221,10 @@ class WorkspaceOneAPI(object):
                 headers=header,
                 timeout=timeout,
             )
-            r = self._check_for_error(r)
-            return r
-        except WorkspaceOneAPIError as e:
-            raise e
+            api_response = self._check_for_error(api_response)
+            return api_response
+        except WorkspaceOneAPIError as api_error:
+            raise api_error
 
     @staticmethod
     def _check_for_error(response):
